@@ -3,12 +3,9 @@ from typing import Tuple, List, Dict
 
 from tqdm import tqdm
 from maggma.builders import Builder
-from maggma.stores import MongoURIStore
-from monty.serialization import loadfn
 from pymatgen.core.structure import Structure
 from matminer.datasets import load_dataset
 
-from emmet.core.alloys import AlloyPairDoc
 from pymatgen.analysis.alloys.core import (
     AlloyPair,
     InvalidAlloy,
@@ -96,9 +93,7 @@ class AlloyPairBuilder(Builder):
                 {"material_id": {"$in": mpids}},
                 properties=["material_id", "band_gap", "is_gap_direct"],
             )
-            electronic_structure_docs = {
-                d["material_id"]: d for d in electronic_structure_docs
-            }
+            electronic_structure_docs = {d["material_id"]: d for d in electronic_structure_docs}
 
             provenance_docs = self.provenance.query(
                 {"material_id": {"$in": mpids}},
@@ -117,16 +112,12 @@ class AlloyPairBuilder(Builder):
                 d["structure"] = Structure.from_dict(d["structure"])
 
                 if material_id in oxi_states_docs:
-                    d["structure_oxi"] = Structure.from_dict(
-                        oxi_states_docs[material_id]["structure"]
-                    )
+                    d["structure_oxi"] = Structure.from_dict(oxi_states_docs[material_id]["structure"])
                 else:
                     d["structure_oxi"] = d["structure"]
 
                 # calculate loose space group
-                d["spacegroup_loose"] = d["structure"].get_space_group_info(
-                    LOOSE_SPACEGROUP_SYMPREC
-                )[1]
+                d["spacegroup_loose"] = d["structure"].get_space_group_info(LOOSE_SPACEGROUP_SYMPREC)[1]
 
                 d["properties"] = {}
                 # patch in BoltzTraP data if present
@@ -137,9 +128,7 @@ class AlloyPairBuilder(Builder):
 
                 if material_id in electronic_structure_docs:
                     for key in ("band_gap", "is_gap_direct"):
-                        d["properties"][key] = electronic_structure_docs[material_id][
-                            key
-                        ]
+                        d["properties"][key] = electronic_structure_docs[material_id][key]
 
                 for key in ("energy_above_hull", "formation_energy_per_atom"):
                     d["properties"][key] = thermo_docs[material_id][key]
@@ -148,9 +137,7 @@ class AlloyPairBuilder(Builder):
                     for key in ("theoretical",):
                         d["properties"][key] = provenance_docs[material_id][key]
 
-            print(
-                f"Starting {af} with {len(docs)} materials, anonymous formula {idx} of {len(ANON_FORMULAS)}"
-            )
+            print(f"Starting {af} with {len(docs)} materials, anonymous formula {idx} of {len(ANON_FORMULAS)}")
 
             yield docs
 
@@ -158,10 +145,7 @@ class AlloyPairBuilder(Builder):
 
         pairs = []
         for mpids in tqdm(list(combinations(item.keys(), 2))):
-            if (
-                item[mpids[0]]["symmetry"]["number"]
-                == item[mpids[1]]["symmetry"]["number"]
-            ) or (
+            if (item[mpids[0]]["symmetry"]["number"] == item[mpids[1]]["symmetry"]["number"]) or (
                 item[mpids[0]]["spacegroup_loose"] == item[mpids[1]]["spacegroup_loose"]
             ):
                 # optionally, could restrict based on band gap too (e.g. at least one end-point semiconducting)
@@ -220,15 +204,14 @@ class AlloyPairMemberBuilder(Builder):
         self.alloy_pair_members = alloy_pair_members
 
         super().__init__(
-            sources=[alloy_pairs, materials, snls], targets=[alloy_pair_members],
+            sources=[alloy_pairs, materials, snls],
+            targets=[alloy_pair_members],
         )
 
     def get_items(self):
 
         all_alloy_chemsys = set(alloy_pairs.distinct("alloy_pair.chemsys"))
-        all_known_chemsys = set(self.materials.distinct("chemsys")) | set(
-            self.snls.distinct("chemsys")
-        )
+        all_known_chemsys = set(self.materials.distinct("chemsys")) | set(self.snls.distinct("chemsys"))
         possible_chemsys = all_known_chemsys.intersection(all_alloy_chemsys)
 
         print(
@@ -245,11 +228,11 @@ class AlloyPairMemberBuilder(Builder):
                 criteria={"chemsys": chemsys, "deprecated": False},
                 properties=["structure", "material_id"],
             )
-            mp_structures = {
-                d["material_id"]: Structure.from_dict(d["structure"]) for d in mp_docs
-            }
+            mp_structures = {d["material_id"]: Structure.from_dict(d["structure"]) for d in mp_docs}
 
-            snl_docs = self.snls.query({"chemsys": chemsys},)
+            snl_docs = self.snls.query(
+                {"chemsys": chemsys},
+            )
             snl_structures = {d["snl_id"]: Structure.from_dict(d) for d in snl_docs}
 
             structures = mp_structures
@@ -299,9 +282,7 @@ class AlloySystemBuilder(Builder):
     It also builds AlloySystem.
     """
 
-    def __init__(
-        self, alloy_pairs, alloy_pair_members, alloy_pairs_merged, alloy_systems
-    ):
+    def __init__(self, alloy_pairs, alloy_pair_members, alloy_pairs_merged, alloy_systems):
 
         self.alloy_pairs = alloy_pairs
         self.alloy_pair_members = alloy_pair_members
@@ -324,10 +305,7 @@ class AlloySystemBuilder(Builder):
 
             docs = list(self.alloy_pairs.query({"alloy_pair.anonymous_formula": af}))
             pair_ids = [d["pair_id"] for d in docs]
-            members = {
-                d["pair_id"]: d
-                for d in self.alloy_pair_members.query({"pair_id": {"$in": pair_ids}})
-            }
+            members = {d["pair_id"]: d for d in self.alloy_pair_members.query({"pair_id": {"$in": pair_ids}})}
 
             if docs:
                 yield docs, members
@@ -339,9 +317,7 @@ class AlloySystemBuilder(Builder):
         for doc in pair_docs:
             if doc["pair_id"] in members:
                 doc["alloy_pair"]["members"] = members[doc["pair_id"]]["members"]
-                doc["_search"]["member_ids"] = [
-                    m["id_"] for m in members[doc["pair_id"]]["members"]
-                ]
+                doc["_search"]["member_ids"] = [m["id_"] for m in members[doc["pair_id"]]["members"]]
             else:
                 doc["alloy_pair"]["members"] = []
                 doc["_search"]["member_ids"] = []
